.. dyndnsc documentation master file

Welcome to Dyndnsc's documentation!
===================================

User Guide
----------

This part of the documentation, which is mostly prose, begins with some
background information about Dyndnsc, then focuses on step-by-step
instructions for getting the most out of Dyndnsc.

.. toctree::
   :maxdepth: 2

   user/intro
   user/install
   user/quickstart
   user/faq
   user/updates
   user/license


API Documentation
-----------------

If you are looking for information on a specific function, class or method,
this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api

Contributor Guide
-----------------

If you want to contribute to the project, this part of the documentation is for
you.

.. toctree::
   :maxdepth: 2

   dev/contrib

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

